## Data for Partial Volume Deflagration Experiments with Synthesized Lithium-Ion Battery Thermal Runaway Effluent Gas.

This dataset is associated with the FSRI study of the explosion hazards of lithium-ion battery gas in a residential garage structure. Additional information can be found at [FSRI.org](https://fsri.org/).

__Nathaniel G. Sauer__
Data processing, writing, repository setup.

__Benjamin Gaudet__
Experimental execution, data processing.

__Adam Barowy__
Project inception, funding, planning, experimental execution.


### Introduction

This dataset contains pressure (raw and processed), methane gas concentration (ATO), gas explosibility properties, and sensor information for 19 tests, an overview of which is provided in the table in the test summary section below. This complete experimental matrix is also provided in a downloadable information file. 

***Flammable Gas***
These tests were conducted using a synthesized battery gas. The concentrations of gas species comprising the simulated battery gas are provided below as well as in `General_info.xlsx`. These gas concentrations, as well as the explosibility properties, were determined experimentally.

*Table 1: Composition of Simulated Battery Effluent Gas Mixture*
|                     | % Volume of Gas |        |       |        |
|---------------------|:----------------|:-------|:------|:-------|
| Simulated Chemistry | CO              |   CO2  |   H2  |   CH4  |
| NCA                 | 36.21           | 22.16  | 32.89 | 8.74   |
| LFP                 | 9.00            | 20.00  | 50.00 | 21.00  |

***Bags/ Release***
Tests are denoted either 'bag' or 'dispersion'. Bag experiments denote mixtures of flammable gas and air at maximum burning velocity concentration inside of a 0.06 mm thick polyethylene bags. The composition inside of the bag was mixed with an explosion proof blower and recirculation loop until the desired fuel concentration was measured in the bag via non-dispersive infrared (Teledyne Gasurveyor 700) sensor, the blower was then turned off and turbulence allowed to settle for 60 seconds.  Volumes of the bags and volumes of the flammable gas used in the mixture are both presented in Table 2. Release experiments denote cases where the flammable gas was released through a 2.5 cm (1 in) orifice at a rate of 527 L/min behind a simulated Residential Energy Storage System (RESS) enclosure at 100% concentration and allowed to disperse naturally in the garage enclosure. Bag tests were ignited using an MJG Technologies Firewire as a single point pyrotechnic initiator. Dispersion tests were ignited using a shower of sparks from a Le Maitre Gerb electrically initiated chemical pyrotechnic.

***Structure***
The garage enclosure consisted of a 6.1 m wide by 6.1 m long by 3.1 m tall interior garage space, supported by a secondary space and additional exterior walls to simulate stiffness granted by additional structure of a normal residence. Walls were constructed of 5.1 cm (2 in) by 12.7 cm (4 in) SPF #2 wooden studs spaced 61 cm (24 in) from center to center, with vinyl siding over 1.3 cm (0.5 in) thick fiberboard, and 1.6 cm (0.625 in) thick Type X gypsum wallboard on the interior with no painted surfaces. The garage door used was a 4.9 m (16 ft) wide by 2.1 m (7 ft) tall steel overhead door. A 76 cm (30 in) wide by 203 cm (80 in) tall steel-over-polystyrene core 20-minute fire-rated interior door was installed in the center of the opposite wall to the garage door. 

***Pressure Sensors***
Pressure data was obtained via flush mount PCB Piezotronics high-frequency ICP® 113B28 piezoelectric pressure transducers connected to a 481A PCB signal conditioner using 003C10 low-noise coaxial cable. These sensors have a measurement range of 344.7 kPa, sensitivity ± 14.5 mV/kPa, rise time ≤ 1.0 μs and a resolution of 0.007 kPa. PCB Model 137B23B pencil probes were also used, these sensors have measurement range of 345 kPa, sensitivity ± 14.5 mV/kPa, rise time ≤ 6.5 μs and a resolution of 0.069 kPa. Thirteen of these pressure sensors were placed in and around the garage enclosure. Locations of sensors in both the bag and dispersion experiments are included in the `sensors.pdf` file. Pressure data was originally recorded at 20 kHz with a Yokogawa DL950 data acquisition recorder. Data recording was triggered simultaneously with the ignition equipment. Data were acquired 1 second before and 9 seconds after the ignition trigger. Original raw datafiles are included where sensor information is presented as voltage only, processed data files are also provided where data has been reduced to 5 kHz and voltages have been converted to pressure (or distance for string potentiometers, see below), these files have also been trimmed to focus on the time-region of interest (-1 to +0.5 seconds relative to ignition).


***Gas Concentration Data***
Gas concentration data was obtained for release experiments using four portable methane gas detectors (ATO model GD200-CH4). Methane concentration was measured at three locations along the ceiling and one central location inside of the garage enclosure (locations in `sensors.pdf`). These devices use a built-in diaphragm pump and non-dispersive infrared gas sensor calibrated for methane to measure and record methane concentration at 0.2 kHz. During the analysis of these data, it was assumed that the relative concentrations of gas species in the flammable gas mixture stayed constant as the mixture dispersed and entrained air. It was also assumed that the methane measurement was a suitable proxy to infer the volume fraction of the overall flammable gas mixture. Data files provided for gas concentration are already converted from methane to total flammable gas concentration.

**Other Instrumentation**
UniMeasure Model PA-25 string potentiometers were also used on the A-side (garage door) and B-side walls, these sensors had a range of 63.5 cm, linearity of ± 0.15% full scale and repeatability of ± 0.015% full scale. String potentiometer data was recorded simultaneously with pressure data and is available in both the raw and converted data files.

### Test Summary
*Table 2: Test Summary*
| Test_ID | File_ID | Type    | synTREG | Vflamgas (L) | Vbag (L) | %LFL (room) | Vgas (m^3) | V% tot | phi (room) |
|---------|---------|---------|---------|----------------|------------|---------------|---------------|----------|--------------|
| Test_1  | 0103    | Bag     | NCA     | 31             | 83         | 0.25          | 0.031         | 0.027    | 0.0007       |
| Test_2  | 0105    | Bag     | NCA     | 62             | 165        | 0.50          | 0.062         | 0.055    | 0.0014       |
| Test_3  | 0106    | Bag     | NCA     | 124            | 330        | 1.00          | 0.124         | 0.109    | 0.0028       |
| Test_4  | 0107    | Bag     | NCA     | 62             | 165        | 0.50          | 0.062         | 0.055    | 0.0014       |
| Test_5  | 0108    | Bag     | NCA     | 1238           | 3302       | 10.00         | 1.238         | 1.091    | 0.0284       |
| Test_6  | 0109    | Bag     | NCA     | 619            | 1651       | 5.00          | 0.619         | 0.546    | 0.0141       |
| Test_7  | 0110    | Bag     | NCA     | 310            | 826        | 2.50          | 0.310         | 0.273    | 0.0070       |
| Test_8  | 0111    | Bag     | LFP     | 24             | 85         | 0.35          | 0.024         | 0.021    | 0.0007       |
| Test_9  | 0112    | Bag     | LFP     | 45             | 170        | 0.67          | 0.045         | 0.040    | 0.0013       |
| Test_10 | 0113    | Bag     | LFP     | 91             | 320        | 1.34          | 0.091         | 0.080    | 0.0027       |
| Test_11 | 0114    | Dispersion | NCA     | 310            | N/A        | 2.50          | 0.3100        | 0.273    | 0.0070       |
| Test_12 | 0115    | Dispersion | NCA     | 619            | N/A        | 5.00          | 0.6190        | 0.545    | 0.0141       |
| Test_13 | 0116    | Dispersion | NCA     | 1238           | N/A        | 10.00         | 1.2380        | 1.091    | 0.0284       |
| Test_14 | 0117    | Dispersion | NCA     | 3095           | N/A        | 25.00         | 3.0950        | 2.727    | 0.0721       |
| Test_15 | 0118    | Dispersion | NCA     | 3095           | N/A        | 25.00         | 3.0950        | 2.727    | 0.0721       |
| Test_16 | 0119    | Dispersion | NCA     | 10008          | N/A        | 80.82         | 10.008        | 8.818    | 0.2487       |
| Test_17 | 0122    | Dispersion | NCA     | 7506           | N/A        | 110.22        | 7.5060        | 6.613    | 0.1821       |
| Test_18 | 0123    | Dispersion | LFP     | 6809           | N/A        | 100.00        | 6.8090        | 5.999    | 0.2137       |


### Repository Structure

As mentioned, this repository includes zip files containing complete 20 kHz raw voltage files (`/Raw_sensor_voltage/`), decimated converted and time-windowed data files (`/Data_converted_decimated/`), gas concentration data (`/ATO_data/`) and explosibility properties (`/Pmax - SL/`). Also included is a general information folder with an information file `General_info.xlsx` on the test matrix, gas composition, channel names, and sensor conversion factors as well as the sensor location drawing `sensors.pdf`. The folder structure is below with files within named for each test apart from the raw sensor voltage files which are named by **File_ID** in the table above.

- `/ATO_data/`
- `/General/`
- `/Pmax - SL/`
- `/Data_converted_decimated/`
- `/Raw_sensor_voltage/`


